@@ -45,13 +45,25 @@ class ExceptionHandler:
                 f"{exception.__class__.__name__}Handler"
             ).handle(exception)
 
-        if hasattr(exception, "get_response"):
-            return response.view(exception.get_response(), exception.get_status())
-
-        handler = Handler(exception)
         if "application/json" in str(request.header("Accept")):
             return response.view(JsonHandler(exception).render(), status=500)
 
+        if not self.application.is_debug():
+            # for HTTP error codes (500, 404, 403...) a specific page should be displayed
+            if hasattr(exception, "is_http_exception"):
+                return self.application.make("HttpExceptionHandler").handle(exception)
+            # if a renderable exception is raised let it be displayed
+            if hasattr(exception, "get_response"):
+                return response.view(exception.get_response(), exception.get_status())
+
+            # else fallback to an unknown exception should be displayed as a 500 error
+            exception.get_status = lambda: 500
+            exception.get_response = lambda: str(exception) or "Unknown error"
+            return self.application.make("HttpExceptionHandler").handle(exception)
+
+        # else display exceptionite error page
+        handler = Handler(exception)
+
         if self.options.get("handlers.stack_overflow"):
             handler.integrate(StackOverflowIntegration())
         if self.options.get("handlers.solutions"):
