@@ -5,6 +5,7 @@ import re
 import tldextract
 from .validation import ValidatesRequest
 from ..authorization import AuthorizesRequest
+from ..sessions import old as old_helper
 
 
 class Request(ValidatesRequest, AuthorizesRequest):
@@ -21,8 +22,11 @@ class Request(ValidatesRequest, AuthorizesRequest):
         self.cookie_jar = CookieJar()
         self.header_bag = HeaderBag()
         self.input_bag = InputBag()
+        self._ip = None
         self.params = {}
         self._user = None
+        self.route = None
+        self._subdomains_activated = False
         self.load()
 
     def load(self):
@@ -39,6 +43,9 @@ class Request(ValidatesRequest, AuthorizesRequest):
     def param(self, param, default=""):
         return self.params.get(param, default)
 
+    def get_route(self):
+        return self.route
+
     def get_path(self):
         return self.environ.get("PATH_INFO")
 
@@ -51,7 +58,7 @@ class Request(ValidatesRequest, AuthorizesRequest):
     def get_request_method(self):
         return self.environ.get("REQUEST_METHOD")
 
-    def input(self, name, default=False):
+    def input(self, name, default=""):
         """Get a specific input value.
 
         Arguments:
@@ -97,6 +104,9 @@ class Request(ValidatesRequest, AuthorizesRequest):
     def only(self, *inputs):
         return self.input_bag.only(*inputs)
 
+    def old(self, key):
+        return old_helper(key)
+
     def is_not_safe(self):
         """Check if the current request is not a get request.
 
@@ -128,6 +138,9 @@ class Request(ValidatesRequest, AuthorizesRequest):
         return regex.match(self.get_path())
 
     def get_subdomain(self, exclude_www=True):
+        if not self._subdomains_activated:
+            return None
+
         url = tldextract.extract(self.get_host())
         if url.subdomain == "" or (
             url.subdomain and exclude_www and url.subdomain == "www"
@@ -138,3 +151,11 @@ class Request(ValidatesRequest, AuthorizesRequest):
 
     def get_host(self):
         return self.environ.get("HTTP_HOST")
+
+    def activate_subdomains(self):
+        self._subdomains_activated = True
+        return self
+
+    def ip(self) -> "str|None":
+        """Return the request IP by processing the different headers setup in IpMiddleware."""
+        return self._ip
