@@ -9,8 +9,8 @@ class TestRequest(TestCase):
         super().setUp()
         self.request = Request(generate_wsgi(path="/test"))
 
-    def test_request_no_input_returns_false(self):
-        self.assertEqual(self.request.input("notavailable"), False)
+    def test_request_no_input_returns_empty_string(self):
+        self.assertEqual(self.request.input("notavailable"), "")
 
     def test_request_can_get_string_value(self):
         self.request.input_bag.query_string = {"test": "value"}
@@ -23,3 +23,8 @@ class TestRequest(TestCase):
     def test_request_can_get_float_value(self):
         self.request.input_bag.query_string = {"test": 3.1415926}
         self.assertEqual(self.request.input("test"), 3.1415926)
+
+    def test_request_can_get_nested_value(self):
+        # from query string
+        self.request.input_bag.query_string = {"key": "val", "a": {"b": {"c": 1}}}
+        self.assertEqual(self.request.input("a.b.c"), 1)
