@@ -1,5 +1,3 @@
-import os
-
 from src.masonite.auth import Sign
 from src.masonite.foundation import response_handler
 from src.masonite.storage import StorageCapsule
@@ -11,6 +9,8 @@ from src.masonite.middleware import (
     EncryptCookies,
     LoadUserMiddleware,
     MaintenanceModeMiddleware,
+    ClearDumpsBetweenRequestsMiddleware,
+    IpMiddleware,
 )
 from src.masonite.routes import Route
 from src.masonite.utils.structures import load
@@ -19,7 +19,12 @@ from src.masonite.utils.location import base_path
 
 class Kernel:
 
-    http_middleware = [EncryptCookies, MaintenanceModeMiddleware]
+    http_middleware = [
+        EncryptCookies,
+        ClearDumpsBetweenRequestsMiddleware,
+        IpMiddleware,
+        MaintenanceModeMiddleware,
+    ]
     route_middleware = {
         "web": [
             SessionMiddleware,
